<?php
#    IRM - The Information Resource Manager
#    Copyright (C) 1999 Yann Ramin
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License (in file COPYING) for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
include("../include/irm.inc");
require_once 'lib/Config.php';

AuthCheck("tech");

if ( @$oem_sticker ) {
	$oem_sticker="Yes";
} else {
	$oem_sticker="No";
}
$vals = array(
	'sID' => $sID,
	'licensekey' => $licensekey,
	'entitlement' => $entitlement,
	'oem_sticker' => $oem_sticker
	);


$DB = Config::Database();
$DB->InsertQuery('software_licenses', $vals);
header("Location: ".appendURLArguments($_SESSION['_sess_prevpage'], array('ID' => $sID)));
